@@ -1,40 +1,51 @@
-from __future__ import absolute_import
 
-import exceptions
+
+import sys
+if sys.version_info < (3,):
+    import exceptions
 import re
 
-class Error(exceptions.StandardError):
+
+class Error(Exception):
     pass
 
-class Warning(exceptions.StandardError):
+
+class Warning(Exception):
     pass
 
+
 class InterfaceError(Error):
     pass
 
+
 class DatabaseError(Error):
     pass
 
+
 class InternalError(DatabaseError):
     pass
 
+
 class OperationalError(DatabaseError):
     pass
 
+
 class ProgrammingError(DatabaseError):
     pass
 
+
 class IntegrityError(DatabaseError):
     pass
 
+
 class DataError(DatabaseError):
     pass
 
+
 class NotSupportedError(DatabaseError):
     pass
 
 
-
 #
 # Other Errors
 #
@@ -43,23 +54,30 @@ class NotSupportedError(DatabaseError):
 class TimedOutError(OperationalError):
     pass
 
+
 class ConnectionError(DatabaseError):
     pass
 
+
 class SSLNotSupported(ConnectionError):
     pass
 
+
 class MessageError(InternalError):
     pass
 
+
 class EmptyQueryError(ProgrammingError):
     pass
 
+
 class QueryError(ProgrammingError):
     def __init__(self, error_response, sql):
         self.error_response = error_response
         self.sql = sql
-        super(QueryError, self).__init__("{0}, SQL: {1}".format(error_response.error_message(), repr(self.one_line_sql())))
+        super(QueryError, self).__init__("{0}, SQL: {1}".format(
+            error_response.error_message(), repr(self.one_line_sql()))
+        )
 
     def one_line_sql(self):
         if self.sql:
@@ -106,19 +124,19 @@ class CopyRejected(QueryError):
 class PermissionDenied(QueryError):
     pass
 
-    
+
 class InvalidDatetimeFormat(QueryError):
     pass
 
 
 QUERY_ERROR_CLASSES = {
-    '55V03': LockFailure,
-    '53000': InsufficientResources,
-    '53200': OutOfMemory,
-    '42601': VerticaSyntaxError,
-    '42V01': MissingRelation,
-    '42703': MissingColumn,
-    '22V04': CopyRejected,
-    '42501': PermissionDenied,
-    '22007': InvalidDatetimeFormat
+    b'55V03': LockFailure,
+    b'53000': InsufficientResources,
+    b'53200': OutOfMemory,
+    b'42601': VerticaSyntaxError,
+    b'42V01': MissingRelation,
+    b'42703': MissingColumn,
+    b'22V04': CopyRejected,
+    b'42501': PermissionDenied,
+    b'22007': InvalidDatetimeFormat
 }
